@@ -1,10 +1,7 @@
 import logging
-import datetime
-from urllib import parse
 from urllib3.util import Retry
-import warnings
 
-from requests import Request, Session, Response
+from requests import Session, Response
 from requests.exceptions import HTTPError, Timeout
 from requests.adapters import HTTPAdapter
 from cachecontrol import CacheControlAdapter
@@ -18,7 +15,7 @@ from .wrappers import (
     _default_to_locale,
     _inject_user_id,
 )
-from .base_client import _BaseClient, TOKEN_EXPIRED_MSG, BASE_URI
+from .base_client import _BaseClient, TOKEN_EXPIRED_MSG
 
 
 logger = logging.getLogger(__name__)
@@ -261,9 +258,7 @@ class Spotify(_BaseClient):
         self._update_user_creds_with(new_creds_obj)
 
     @_set_empty_user_creds_if_none
-    def build_user_creds(
-        self, grant, set_user_creds=True
-    ):
+    def build_user_creds(self, grant, set_user_creds=True):
         """
         Second part of OAuth2 authorization code flow, Raises an AuthError if unauthorized
 
@@ -972,6 +967,33 @@ class Spotify(_BaseClient):
         """
         return args, kwargs
 
+    @_dispatch_request
+    def replace_playlist_tracks(self, *args, **kwargs):
+        """
+        Replace all tracks of a playlist with tracks of your choice
+
+        Arguments:
+
+            playlist_id:
+
+                * Required
+
+            track_ids:
+
+                * track_ids not full URIs
+
+                * Optional
+
+        Returns:
+
+            dict:
+
+        Raises:
+
+            pyfy.excs.ApiError:
+        """
+        return args, kwargs
+
     @_dispatch_request
     def delete_playlist_tracks(self, *args, **kwargs):
         """
